@@ -1,7 +1,7 @@
 /**
  * @file db.c sqlite backend
  * 
- * Copyright (C) 2007-2012  Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2007-2020  Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +31,6 @@
 #include "metadata.h"
 #include "vfolder.h"
 
-/* You can find a schema description used by this version of Liferea at:
-   https://lzone.de/wiki/doku.php?id=liferea:v1.8:db_schema */
-
 static sqlite3	*db = NULL;
 gboolean searchFolderRebuild = FALSE;
 
@@ -568,6 +565,10 @@ db_init (void)
 	db_exec ("DELETE FROM subscription_metadata WHERE node_id NOT IN "
           	 "(SELECT node_id FROM node);");
 
+	debug0 (DEBUG_DB, "Removing metadata without item...\n");
+	db_exec ("DELETE FROM metadata WHERE item_id NOT IN "
+		 "(SELECT item_id FROM items);");
+
 	debug0 (DEBUG_DB, "DB cleanup finished. Continuing startup.");
 		
 	/* 4. Creating triggers (after cleanup so it is not slowed down by triggers) */
