@@ -1,13 +1,13 @@
 /**
  * @file google_reader_api_edit.c  Google Reader API syncing support
- * 
+ *
  * Copyright (C) 2008 Arnold Noronha <arnstein87@gmail.com>
  * Copyright (C) 2014-2015 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version. 
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,19 +31,19 @@
 /**
  * A structure to indicate an edit to the node source remote feed "database".
  * These edits are put in a queue and processed in sequential order
- * so that the API endpoint does not end up processing the requests in an 
+ * so that the API endpoint does not end up processing the requests in an
  * unintended order.
  */
 typedef struct GoogleReaderAction {
 	/**
-	 * The guid of the item to edit. This will be ignored if the 
+	 * The guid of the item to edit. This will be ignored if the
 	 * edit is acting on an subscription rather than an item.
 	 */
 	gchar* guid;
 
 	/**
-	 * A MANDATORY feed url to containing the item, or the url of the 
-	 * subscription to edit. 
+	 * A MANDATORY feed url to containing the item, or the url of the
+	 * subscription to edit.
 	 */
 	gchar* feedUrl;
 
@@ -82,7 +82,7 @@ typedef struct GoogleReaderAction {
 	gchar *response;
 } *GoogleReaderActionPtr;
 
-enum { 
+enum {
 	EDIT_ACTION_MARK_READ,
 	EDIT_ACTION_MARK_UNREAD,
 	EDIT_ACTION_TRACKING_MARK_UNREAD, /**< every UNREAD request, should be followed by tracking-kept-unread */
@@ -95,14 +95,14 @@ enum {
 
 typedef struct GoogleReaderAction* editPtr;
 
-typedef struct GoogleReaderActionCtxt { 
+typedef struct GoogleReaderActionCtxt {
 	gchar			*nodeId;
-	GoogleReaderActionPtr	action; 
-} *GoogleReaderActionCtxtPtr; 
+	GoogleReaderActionPtr	action;
+} *GoogleReaderActionCtxtPtr;
 
 static void google_reader_api_edit_push (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean head);
 
-static GoogleReaderActionPtr 
+static GoogleReaderActionPtr
 google_reader_api_action_new (int actionType)
 {
 	GoogleReaderActionPtr action = g_slice_new0 (struct GoogleReaderAction);
@@ -110,9 +110,9 @@ google_reader_api_action_new (int actionType)
 	return action;
 }
 
-static void 
+static void
 google_reader_api_action_free (GoogleReaderActionPtr action)
-{ 
+{
 	g_free (action->guid);
 	g_free (action->feedUrl);
 	g_free (action->label);
@@ -136,19 +136,19 @@ google_reader_api_action_context_free(GoogleReaderActionCtxtPtr ctxt)
 }
 
 static void
-google_reader_api_edit_action_complete (const struct updateResult* const result, gpointer userdata, updateFlags flags) 
-{ 
-	GoogleReaderActionCtxtPtr	editCtxt = (GoogleReaderActionCtxtPtr) userdata; 
+google_reader_api_edit_action_complete (const struct updateResult* const result, gpointer userdata, updateFlags flags)
+{
+	GoogleReaderActionCtxtPtr	editCtxt = (GoogleReaderActionCtxtPtr) userdata;
 	GoogleReaderActionPtr		action = editCtxt->action;
 	nodePtr				node = node_from_id (editCtxt->nodeId);
 	gboolean			failed = FALSE;
-	
+
 	google_reader_api_action_context_free (editCtxt);
 
 	if (!node) {
 		google_reader_api_action_free (action);
 		return; /* probably got deleted before this callback */
-	} 
+	}
 
 	// FIXME: suboptimal check as some results are text, some XML, some JSON...
 	if (!g_str_equal (result->data, "OK")) {
@@ -193,11 +193,11 @@ google_reader_api_edit_action_complete (const struct updateResult* const result,
 	google_reader_api_edit_process (node->source);
 }
 
-/* the following google_reader_api_* functions are simply functions that 
-   convert a GoogleReaderActionPtr to a updateRequestPtr */
- 
+/* the following google_reader_api_* functions are simply functions that
+   convert a GoogleReaderActionPtr to a UpdateRequest */
+
 static void
-google_reader_api_add_subscription (GoogleReaderActionPtr action, updateRequestPtr request, const gchar* token) 
+google_reader_api_add_subscription (GoogleReaderActionPtr action, UpdateRequest *request, const gchar* token)
 {
 	update_request_set_source (request, action->source->type->api.add_subscription);
 	gchar *s_escaped = g_uri_escape_string (action->feedUrl, NULL, TRUE);
@@ -206,7 +206,7 @@ google_reader_api_add_subscription (GoogleReaderActionPtr action, updateRequestP
 }
 
 static void
-google_reader_api_remove_subscription (GoogleReaderActionPtr action, updateRequestPtr request, const gchar* token) 
+google_reader_api_remove_subscription (GoogleReaderActionPtr action, UpdateRequest *request, const gchar* token)
 {
 	update_request_set_source (request, action->source->type->api.remove_subscription);
 	gchar* s_escaped = g_uri_escape_string (action->feedUrl, NULL, TRUE);
@@ -216,7 +216,7 @@ google_reader_api_remove_subscription (GoogleReaderActionPtr action, updateReque
 }
 
 static void
-google_reader_api_add_label (GoogleReaderActionPtr action, updateRequestPtr request, const gchar* token)
+google_reader_api_add_label (GoogleReaderActionPtr action, UpdateRequest *request, const gchar* token)
 {
 	update_request_set_source (request, action->source->type->api.edit_add_label);
 	gchar* s_escaped = g_uri_escape_string (action->feedUrl, NULL, TRUE);
@@ -226,12 +226,12 @@ google_reader_api_add_label (GoogleReaderActionPtr action, updateRequestPtr requ
 	g_free (s_escaped);
 }
 
-static void 
-google_reader_api_edit_tag (GoogleReaderActionPtr action, updateRequestPtr request, const gchar *token) 
+static void
+google_reader_api_edit_tag (GoogleReaderActionPtr action, UpdateRequest *request, const gchar *token)
 {
-	update_request_set_source (request, action->source->type->api.edit_tag); 
+	update_request_set_source (request, action->source->type->api.edit_tag);
 
-	const gchar* prefix = "feed"; 
+	const gchar* prefix = "feed";
 	gchar* s_escaped = g_uri_escape_string (action->feedUrl, NULL, TRUE);
 	gchar* a_escaped = NULL;
 	gchar* i_escaped = g_uri_escape_string (action->guid, NULL, TRUE);;
@@ -244,12 +244,12 @@ google_reader_api_edit_tag (GoogleReaderActionPtr action, updateRequestPtr reque
 	 * tag:google.com,2005:reader/user/<sharer's-id>/source/com.google/link
 	 * It is possible that there are items other thank link that has
 	 * the ../user/.. id. The GR API requires the strings after ..:reader/
-	 * while GoogleReaderAction only gives me after :reader/feed/ (or 
+	 * while GoogleReaderAction only gives me after :reader/feed/ (or
 	 * :reader/user/ as the case might be). I therefore need to guess
-	 * the prefix ('feed/' or 'user/') from just this information. 
+	 * the prefix ('feed/' or 'user/') from just this information.
 	 */
 
-	if (strstr(action->feedUrl, "://") == NULL) 
+	if (strstr(action->feedUrl, "://") == NULL)
 		prefix = "user" ;
 
 	if (action->actionType == EDIT_ACTION_MARK_UNREAD) {
@@ -258,15 +258,15 @@ google_reader_api_edit_tag (GoogleReaderActionPtr action, updateRequestPtr reque
 		postdata = g_strdup_printf (action->source->type->api.edit_tag_ar_tag_post, i_escaped, prefix, s_escaped, a_escaped, r_escaped, token);
 		g_free (r_escaped);
 	}
-	else if (action->actionType == EDIT_ACTION_MARK_READ) { 
+	else if (action->actionType == EDIT_ACTION_MARK_READ) {
 		a_escaped = g_uri_escape_string (GOOGLE_READER_TAG_READ, NULL, TRUE);
 		postdata = g_strdup_printf (action->source->type->api.edit_tag_add_post, i_escaped, prefix, s_escaped, a_escaped, token);
 	}
 	else if (action->actionType == EDIT_ACTION_TRACKING_MARK_UNREAD) {
 		a_escaped = g_uri_escape_string (GOOGLE_READER_TAG_TRACKING_KEPT_UNREAD, NULL, TRUE);
 		postdata = g_strdup_printf (action->source->type->api.edit_tag_add_post, i_escaped, prefix, s_escaped, a_escaped, token);
-	}  
-	else if (action->actionType == EDIT_ACTION_MARK_STARRED) { 
+	}
+	else if (action->actionType == EDIT_ACTION_MARK_STARRED) {
 		a_escaped = g_uri_escape_string (GOOGLE_READER_TAG_STARRED, NULL, TRUE) ;
 		postdata = g_strdup_printf (action->source->type->api.edit_tag_add_post, i_escaped, prefix,
 			s_escaped, a_escaped, token);
@@ -276,11 +276,11 @@ google_reader_api_edit_tag (GoogleReaderActionPtr action, updateRequestPtr reque
 		postdata = g_strdup_printf (action->source->type->api.edit_tag_remove_post, i_escaped, prefix,
 			s_escaped, r_escaped, token);
 	}
-	
+
 	else g_assert (FALSE);
-	
+
 	g_free (s_escaped);
-	g_free (a_escaped); 
+	g_free (a_escaped);
 	g_free (i_escaped);
 
 	request->postdata = postdata;
@@ -288,42 +288,44 @@ google_reader_api_edit_tag (GoogleReaderActionPtr action, updateRequestPtr reque
 
 static void
 google_reader_api_edit_token_cb (const struct updateResult * const result, gpointer userdata, updateFlags flags)
-{ 
-	nodePtr          node;
-	const gchar*     token;
+{
+	nodePtr		node;
+	const gchar*	token;
 	GoogleReaderActionPtr          action;
-	updateRequestPtr request; 
+	UpdateRequest	*request;
 
-	if (result->httpstatus != 200 || result->data == NULL) { 
+	if (result->httpstatus != 200 || result->data == NULL) {
 		/* FIXME: What is the behaviour that should go here? */
 		return;
 	}
 
 	node = node_from_id ((gchar*) userdata);
 	g_free (userdata);
-	
+
 	if (!node)
 		return;
 
-	token = result->data; 
+	token = result->data;
 
 	if (!node->source || g_queue_is_empty (node->source->actionQueue))
 		return;
 
 	action = g_queue_peek_head (node->source->actionQueue);
 
-	request = update_request_new ();
-	request->updateState = update_state_copy (node->subscription->updateState);
-	request->options = update_options_copy (node->subscription->updateOptions) ;
+	request = update_request_new (
+		"NOT THE REAL URL",	// real URL will be set later based on action
+		node->subscription->updateState,
+		node->subscription->updateOptions
+	);
 	update_request_set_auth_value (request, node->source->authToken);
 
-	if (action->actionType == EDIT_ACTION_MARK_READ || 
-	    action->actionType == EDIT_ACTION_MARK_UNREAD || 
+	if (action->actionType == EDIT_ACTION_MARK_READ ||
+	    action->actionType == EDIT_ACTION_MARK_UNREAD ||
 	    action->actionType == EDIT_ACTION_TRACKING_MARK_UNREAD ||
-	    action->actionType == EDIT_ACTION_MARK_STARRED || 
-	    action->actionType == EDIT_ACTION_MARK_UNSTARRED) 
+	    action->actionType == EDIT_ACTION_MARK_STARRED ||
+	    action->actionType == EDIT_ACTION_MARK_UNSTARRED)
 		google_reader_api_edit_tag (action, request, token);
-	else if (action->actionType == EDIT_ACTION_ADD_SUBSCRIPTION) 
+	else if (action->actionType == EDIT_ACTION_ADD_SUBSCRIPTION)
 		google_reader_api_add_subscription (action, request, token);
 	else if (action->actionType == EDIT_ACTION_REMOVE_SUBSCRIPTION)
 		google_reader_api_remove_subscription (action, request, token);
@@ -338,32 +340,33 @@ google_reader_api_edit_token_cb (const struct updateResult * const result, gpoin
 
 void
 google_reader_api_edit_process (nodeSourcePtr source)
-{ 
-	updateRequestPtr request; 
-	
+{
+	UpdateRequest *request;
+
 	g_assert (source);
 	if (g_queue_is_empty (source->actionQueue))
 		return;
-	
+
 	/*
- 	* Google reader has a system of tokens. So first, I need to request a 
+ 	* Google reader has a system of tokens. So first, I need to request a
  	* token from google, before I can make the actual edit request. The
- 	* code here is the token code, the actual edit commands are in 
+ 	* code here is the token code, the actual edit commands are in
  	* google_reader_api_edit_token_cb
 	 */
-	request = update_request_new ();
-	request->updateState = update_state_copy (source->root->subscription->updateState);
-	request->options = update_options_copy (source->root->subscription->updateOptions);
-	request->source = g_strdup (source->type->api.token);
+	request = update_request_new (
+		source->type->api.token,
+		source->root->subscription->updateState,
+		source->root->subscription->updateOptions
+	);
 	update_request_set_auth_value(request, source->authToken);
 
-	update_execute_request (source, request, google_reader_api_edit_token_cb, 
+	update_execute_request (source, request, google_reader_api_edit_token_cb,
 	                        g_strdup(source->root->id), 0);
 }
 
 static void
 google_reader_api_edit_push_ (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean head)
-{ 
+{
 	g_assert (source->actionQueue);
 	action->source = source;
 	if (head)
@@ -372,7 +375,7 @@ google_reader_api_edit_push_ (nodeSourcePtr source, GoogleReaderActionPtr action
 		g_queue_push_tail (source->actionQueue, action);
 }
 
-static void 
+static void
 google_reader_api_edit_push (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean head)
 {
 	g_assert (source);
@@ -380,14 +383,14 @@ google_reader_api_edit_push (nodeSourcePtr source, GoogleReaderActionPtr action,
 	google_reader_api_edit_push_ (source, action, head);
 
 	/** @todo any flags I should specify? */
-	if (source->loginState == NODE_SOURCE_STATE_NONE) 
+	if (source->loginState == NODE_SOURCE_STATE_NONE)
 		subscription_update (source->root->subscription, NODE_SOURCE_UPDATE_ONLY_LOGIN);
-	else if (source->loginState == NODE_SOURCE_STATE_ACTIVE) 
+	else if (source->loginState == NODE_SOURCE_STATE_ACTIVE)
 		google_reader_api_edit_process (source);
 }
 
-static void 
-update_read_state_callback (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success) 
+static void
+update_read_state_callback (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success)
 {
 	if (!success)
 		debug0 (DEBUG_UPDATE, "Failed to change item state!");
@@ -404,9 +407,9 @@ google_reader_api_edit_mark_read (nodeSourcePtr source, const gchar *guid, const
 	action->callback = update_read_state_callback;
 	google_reader_api_edit_push (source, action, FALSE);
 
-	if (newStatus == FALSE) { 
+	if (newStatus == FALSE) {
 		/*
-		 * According to the Google Reader API, to mark an item unread, 
+		 * According to the Google Reader API, to mark an item unread,
 		 * I also need to mark it as tracking-kept-unread in a separate
 		 * network call.
 		 */
@@ -418,7 +421,7 @@ google_reader_api_edit_mark_read (nodeSourcePtr source, const gchar *guid, const
 }
 
 static void
-update_starred_state_callback(nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success) 
+update_starred_state_callback(nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success)
 {
 	if (!success)
 		debug0 (DEBUG_UPDATE, "Failed to change item state!");
@@ -432,7 +435,7 @@ google_reader_api_edit_mark_starred (nodeSourcePtr source, const gchar *guid, co
 	action->guid = g_strdup (guid);
 	action->feedUrl = g_strdup (feedUrl);
 	action->callback = update_starred_state_callback;
-	
+
 	google_reader_api_edit_push (source, action, FALSE);
 }
 
@@ -441,8 +444,8 @@ google_reader_api_edit_add_subscription_complete (nodeSourcePtr source, GoogleRe
 {
 	/*
 	 * It is possible that remote changed the name of the URL that
-	 * was sent to it. In that case, we need to recover the URL 
-	 * from the list. But a node with the old URL has already 
+	 * was sent to it. In that case, we need to recover the URL
+	 * from the list. But a node with the old URL has already
 	 * been created. Allow the subscription update call to fix that.
 	 */
 	GSList* cur = source->root->children ;
@@ -460,14 +463,14 @@ google_reader_api_edit_add_subscription_complete (nodeSourcePtr source, GoogleRe
 }
 
 static void
-google_reader_api_edit_add_subscription2_cb (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success) 
+google_reader_api_edit_add_subscription2_cb (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success)
 {
 	google_reader_api_edit_add_subscription_complete (source, action);
 }
 
 /* Subscription callback #1 (to set label (folder) before updating the feed list) */
 static void
-google_reader_api_edit_add_subscription_cb (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success) 
+google_reader_api_edit_add_subscription_cb (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success)
 {
 	if (success) {
 		if (action->label) {
@@ -500,7 +503,7 @@ google_reader_api_edit_add_subscription_cb (nodeSourcePtr source, GoogleReaderAc
 	}
 }
 
-void 
+void
 google_reader_api_edit_add_subscription (nodeSourcePtr source, const gchar* feedUrl, const gchar *label)
 {
 	GoogleReaderActionPtr action = google_reader_api_action_new (EDIT_ACTION_ADD_SUBSCRIPTION);
@@ -513,15 +516,15 @@ google_reader_api_edit_add_subscription (nodeSourcePtr source, const gchar* feed
 static void
 google_reader_api_edit_remove_callback (nodeSourcePtr source, GoogleReaderActionPtr action, gboolean success)
 {
-	if (success) {	
-		/* 
+	if (success) {
+		/*
 		 * The node was removed from the feedlist, but could have
 		 * returned because of an update before this edit request
-		 * completed. No cleaner way to handle this. 
+		 * completed. No cleaner way to handle this.
 		 */
 		GSList* cur = source->root->children ;
 		for(; cur; cur = g_slist_next (cur))  {
-			nodePtr node = (nodePtr) cur->data ; 
+			nodePtr node = (nodePtr) cur->data ;
 			if (g_str_equal (node->subscription->source, action->feedUrl)) {
 				feedlist_node_removed (node);
 				return;
@@ -532,20 +535,20 @@ google_reader_api_edit_remove_callback (nodeSourcePtr source, GoogleReaderAction
 }
 
 void
-google_reader_api_edit_remove_subscription (nodeSourcePtr source, const gchar* feedUrl) 
+google_reader_api_edit_remove_subscription (nodeSourcePtr source, const gchar* feedUrl)
 {
-	GoogleReaderActionPtr action = google_reader_api_action_new (EDIT_ACTION_REMOVE_SUBSCRIPTION); 
+	GoogleReaderActionPtr action = google_reader_api_action_new (EDIT_ACTION_REMOVE_SUBSCRIPTION);
 	action->feedUrl = g_strdup (feedUrl);
 	action->callback = google_reader_api_edit_remove_callback;
 	google_reader_api_edit_push (source, action, TRUE);
 }
 
-gboolean google_reader_api_edit_is_in_queue (nodeSourcePtr source, const gchar* guid) 
+gboolean google_reader_api_edit_is_in_queue (nodeSourcePtr source, const gchar* guid)
 {
 	/* this is inefficient, but works for the time being */
-	GList *cur = source->actionQueue->head; 
-	for(; cur; cur = g_list_next (cur)) { 
-		GoogleReaderActionPtr action = cur->data; 
+	GList *cur = source->actionQueue->head;
+	for(; cur; cur = g_list_next (cur)) {
+		GoogleReaderActionPtr action = cur->data;
 		if (action->guid && g_str_equal (action->guid, guid))
 			return TRUE;
 	}
