@@ -44,14 +44,12 @@
 #include "ui/itemview.h"
 
 /** common private structure for all subscription dialogs */
-struct PreferencesDialogPrivate {
+struct _PreferencesDialog {
+	GObject 	parentInstance;
+
 	GtkWidget	*dialog;	/**< the GtkDialog widget */
 };
 
-#define PREFERENCES_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), PREFERENCES_DIALOG_TYPE, PreferencesDialogPrivate))
-
-static GObjectClass *parent_class = NULL;
-
 G_DEFINE_TYPE (PreferencesDialog, preferences_dialog, G_TYPE_OBJECT);
 
 /* file type tree store column ids */
@@ -111,7 +109,6 @@ static const gchar * browser_skim_key_options[] = {
 static const gchar * default_view_mode_options[] = {
 	N_("Normal View"),
 	N_("Wide View"),
-	N_("Combined View"),
 	NULL
 };
 
@@ -140,10 +137,8 @@ preferences_dialog_finalize (GObject *object)
 {
 	PreferencesDialog *pd = PREFERENCES_DIALOG (object);
 
-	gtk_widget_destroy (pd->priv->dialog);
+	gtk_widget_destroy (pd->dialog);
 	prefdialog = NULL;
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
@@ -151,11 +146,7 @@ preferences_dialog_class_init (PreferencesDialogClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->finalize = preferences_dialog_finalize;
-
-	g_type_class_add_private (object_class, sizeof (PreferencesDialogPrivate));
 }
 
 /* Preference callbacks */
@@ -214,9 +205,9 @@ on_browser_changed (GtkComboBox *optionmenu, gpointer user_data)
 	if (gtk_combo_box_get_active_iter (optionmenu, &iter)) {
 		gtk_tree_model_get (gtk_combo_box_get_model (optionmenu), &iter, 1, &num, -1);
 
-		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->priv->dialog, "browsercmd"), num != 0);
-		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->priv->dialog, "manuallabel"), num != 0);
-		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->priv->dialog, "urlhintlabel"), num != 0);
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->dialog, "browsercmd"), num != 0);
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->dialog, "manuallabel"), num != 0);
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->dialog, "urlhintlabel"), num != 0);
 
 		if (!num)
 			conf_set_str_value (BROWSER_ID, "default");
@@ -281,8 +272,8 @@ on_default_update_interval_value_changed (GtkSpinButton *spinbutton, gpointer us
 	gint			updateInterval, intervalUnit;
 	GtkWidget		*unitWidget, *valueWidget;
 
-	unitWidget = liferea_dialog_lookup (prefdialog->priv->dialog, "globalRefreshIntervalUnitComboBox");
-	valueWidget = liferea_dialog_lookup (prefdialog->priv->dialog, "globalRefreshIntervalSpinButton");
+	unitWidget = liferea_dialog_lookup (prefdialog->dialog, "globalRefreshIntervalUnitComboBox");
+	valueWidget = liferea_dialog_lookup (prefdialog->dialog, "globalRefreshIntervalSpinButton");
 	intervalUnit = gtk_combo_box_get_active (GTK_COMBO_BOX (unitWidget));
 	updateInterval = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (valueWidget));
 
@@ -310,21 +301,21 @@ static void
 on_proxyAutoDetect_clicked (GtkButton *button, gpointer user_data)
 {
 	conf_set_int_value (PROXY_DETECT_MODE, 0);
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->priv->dialog, "proxybox")), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->dialog, "proxybox")), FALSE);
 }
 
 static void
 on_noProxy_clicked (GtkButton *button, gpointer user_data)
 {
 	conf_set_int_value (PROXY_DETECT_MODE, 1);
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->priv->dialog, "proxybox")), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->dialog, "proxybox")), FALSE);
 }
 
 static void
 on_manualProxy_clicked (GtkButton *button, gpointer user_data)
 {
 	conf_set_int_value (PROXY_DETECT_MODE, 2);
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->priv->dialog, "proxybox")), TRUE);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->dialog, "proxybox")), TRUE);
 }
 
 void
@@ -332,7 +323,7 @@ on_useProxyAuth_toggled (GtkToggleButton *button, gpointer user_data)
 {
 	gboolean enabled = gtk_toggle_button_get_active (button);
 
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->priv->dialog, "proxyauthtable")), enabled);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog->dialog, "proxyauthtable")), enabled);
 	conf_set_bool_value (PROXY_USEAUTH, enabled);
 }
 
@@ -377,8 +368,8 @@ on_enclosure_download_predefined_toggled (GtkToggleButton *button, gpointer user
 {
 	gboolean is_active = gtk_toggle_button_get_active (button);
 
-	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->priv->dialog, "customDownloadEntry"), !is_active);
-	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->priv->dialog, "downloadToolCombo"), is_active);
+	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->dialog, "customDownloadEntry"), !is_active);
+	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog->dialog, "downloadToolCombo"), is_active);
 	conf_set_bool_value (DOWNLOAD_USE_CUSTOM_COMMAND, !is_active);
 }
 
@@ -402,7 +393,7 @@ on_enc_action_change_btn_clicked (GtkButton *button, gpointer user_data)
 	GtkTreeIter		iter;
 	gpointer		type;
 
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (liferea_dialog_lookup (prefdialog->priv->dialog, "enc_action_view")));
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (liferea_dialog_lookup (prefdialog->dialog, "enc_action_view")));
 	if(gtk_tree_selection_get_selected (selection, &model, &iter)) {
 		gtk_tree_model_get (model, &iter, FTS_PTR, &type, -1);
 		ui_enclosure_change_type (type);
@@ -419,7 +410,7 @@ on_enc_action_remove_btn_clicked (GtkButton *button, gpointer user_data)
 	GtkTreeIter		iter;
 	gpointer		type;
 
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (liferea_dialog_lookup (prefdialog->priv->dialog, "enc_action_view")));
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (liferea_dialog_lookup (prefdialog->dialog, "enc_action_view")));
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 		gtk_tree_model_get (model, &iter, FTS_PTR, &type, -1);
 		gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
@@ -440,6 +431,12 @@ on_donottrackbtn_toggled (GtkToggleButton *button, gpointer user_data)
 	conf_set_bool_value (DO_NOT_TRACK, gtk_toggle_button_get_active (button));
 }
 
+void
+on_itpbtn_toggled (GtkToggleButton *button, gpointer user_data)
+{
+	conf_set_bool_value (ENABLE_ITP, gtk_toggle_button_get_active (button));
+}
+
 static void
 preferences_dialog_destroy_cb (GtkWidget *widget, PreferencesDialog *pd)
 {
@@ -467,8 +464,7 @@ preferences_dialog_init (PreferencesDialog *pd)
 	gchar 			*custom_download_command;
 
 	prefdialog = pd;
-	pd->priv = PREFERENCES_DIALOG_GET_PRIVATE (pd);
-	pd->priv->dialog = liferea_dialog_new ("prefs");
+	pd->dialog = liferea_dialog_new ("prefs");
 
 	/* Set up browser selection popup */
 	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
@@ -477,7 +473,7 @@ preferences_dialog_init (PreferencesDialog *pd)
 	gtk_list_store_append (store, &treeiter);
 	gtk_list_store_set (store, &treeiter, 0, _("Manual"), 1, 1, -1);
 
-	combo = GTK_COMBO_BOX (liferea_dialog_lookup (pd->priv->dialog, "browserpopup"));
+	combo = GTK_COMBO_BOX (liferea_dialog_lookup (pd->dialog, "browserpopup"));
 	gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
 	ui_common_setup_combo_text (combo, 0);
 	g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(on_browser_changed), pd);
@@ -486,21 +482,21 @@ preferences_dialog_init (PreferencesDialog *pd)
 
 	/* check box for feed startup update */
 	conf_get_int_value (STARTUP_FEED_ACTION, &iSetting);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->priv->dialog, "startupactionbtn")), (iSetting == 0));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "startupactionbtn")), (iSetting == 0));
 
 	/* cache size setting */
-	widget = liferea_dialog_lookup (pd->priv->dialog, "itemCountBtn");
+	widget = liferea_dialog_lookup (pd->dialog, "itemCountBtn");
 	itemCount = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (widget));
 	conf_get_int_value (DEFAULT_MAX_ITEMS, &iSetting);
 	gtk_adjustment_set_value (itemCount, iSetting);
 
 	/* set default update interval spin button and unit combo box */
-	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->priv->dialog, "globalRefreshIntervalUnitComboBox"),
+	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->dialog, "globalRefreshIntervalUnitComboBox"),
 	                            default_update_interval_unit_options,
 	                            G_CALLBACK (on_default_update_interval_unit_changed),
 				    -1);
 
-	widget = liferea_dialog_lookup (pd->priv->dialog, "globalRefreshIntervalUnitComboBox");
+	widget = liferea_dialog_lookup (pd->dialog, "globalRefreshIntervalUnitComboBox");
 	conf_get_int_value (DEFAULT_UPDATE_INTERVAL, &tmp);
 	if (tmp % 1440 == 0) {		/* days */
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 2);
@@ -511,30 +507,30 @@ preferences_dialog_init (PreferencesDialog *pd)
 	} else {			/* minutes */
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	}
-	widget = liferea_dialog_lookup (pd->priv->dialog,"globalRefreshIntervalSpinButton");
+	widget = liferea_dialog_lookup (pd->dialog,"globalRefreshIntervalSpinButton");
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (widget), 0, 1000000000);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), tmp);
 	g_signal_connect (G_OBJECT (widget), "changed", G_CALLBACK (on_default_update_interval_value_changed), pd);
 
 	/* ================== panel 2 "folders" ==================== */
 
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "updateAllFavicons")), "clicked", G_CALLBACK(on_updateallfavicons_clicked), pd);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "updateAllFavicons")), "clicked", G_CALLBACK(on_updateallfavicons_clicked), pd);
 
 	conf_get_int_value (FOLDER_DISPLAY_MODE, &iSetting);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->priv->dialog, "folderdisplaybtn")), iSetting?TRUE:FALSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "folderdisplaybtn")), iSetting?TRUE:FALSE);
 	conf_get_bool_value (FOLDER_DISPLAY_HIDE_READ, &bSetting);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->priv->dialog, "hidereadbtn")), bSetting?TRUE:FALSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "hidereadbtn")), bSetting?TRUE:FALSE);
 
 	/* ================== panel 3 "headlines" ==================== */
 
 	conf_get_int_value (BROWSE_KEY_SETTING, &iSetting);
-	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->priv->dialog, "skimKeyCombo"),
+	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->dialog, "skimKeyCombo"),
 	                            browser_skim_key_options,
 	                            G_CALLBACK (on_skim_key_changed),
 	                            iSetting);
 
 	conf_get_int_value (DEFAULT_VIEW_MODE, &iSetting);
-	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->priv->dialog, "defaultViewModeCombo"),
+	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->dialog, "defaultViewModeCombo"),
 	                            default_view_mode_options,
 	                            G_CALLBACK (on_default_view_mode_changed),
 	                            iSetting);
@@ -554,7 +550,7 @@ preferences_dialog_init (PreferencesDialog *pd)
 		i++;
 	}
 
-	combo = GTK_COMBO_BOX (liferea_dialog_lookup (pd->priv->dialog, "socialpopup"));
+	combo = GTK_COMBO_BOX (liferea_dialog_lookup (pd->dialog, "socialpopup"));
 	g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (on_socialsite_changed), pd);
 	gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
 	ui_common_setup_combo_text (combo, 0);
@@ -563,17 +559,17 @@ preferences_dialog_init (PreferencesDialog *pd)
 	/* ================== panel 4 "browser" ==================== */
 
 	/* set the inside browsing flag */
-	widget = liferea_dialog_lookup(pd->priv->dialog, "browseinwindow");
+	widget = liferea_dialog_lookup(pd->dialog, "browseinwindow");
 	conf_get_bool_value(BROWSE_INSIDE_APPLICATION, &bSetting);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), bSetting);
 
 	/* set the javascript-disabled flag */
-	widget = liferea_dialog_lookup(pd->priv->dialog, "disablejavascript");
+	widget = liferea_dialog_lookup(pd->dialog, "disablejavascript");
 	conf_get_bool_value(DISABLE_JAVASCRIPT, &bSetting);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), bSetting);
 
 	/* set the enable Plugins flag */
-	widget = liferea_dialog_lookup(pd->priv->dialog, "enableplugins");
+	widget = liferea_dialog_lookup(pd->dialog, "enableplugins");
 	conf_get_bool_value(ENABLE_PLUGINS, &bSetting);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), bSetting);
 
@@ -581,21 +577,21 @@ preferences_dialog_init (PreferencesDialog *pd)
 	manualBrowser = !strcmp (configuredBrowser, "manual");
 	g_free (configuredBrowser);
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (liferea_dialog_lookup (pd->priv->dialog, "browserpopup")), manualBrowser);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (liferea_dialog_lookup (pd->dialog, "browserpopup")), manualBrowser);
 
 	conf_get_str_value (BROWSER_COMMAND, &browser_command);
-	entry = liferea_dialog_lookup (pd->priv->dialog, "browsercmd");
+	entry = liferea_dialog_lookup (pd->dialog, "browsercmd");
 	gtk_entry_set_text (GTK_ENTRY(entry), browser_command);
 	g_free (browser_command);
 
 	gtk_widget_set_sensitive (GTK_WIDGET (entry), manualBrowser);
-	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->priv->dialog, "manuallabel"), manualBrowser);
-	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->priv->dialog, "urlhintlabel"), manualBrowser);
+	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->dialog, "manuallabel"), manualBrowser);
+	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->dialog, "urlhintlabel"), manualBrowser);
 
 	/* ================== panel 4 "GUI" ================ */
 
 	/* tool bar settings */
-	widget = liferea_dialog_lookup (pd->priv->dialog, "hidetoolbarbtn");
+	widget = liferea_dialog_lookup (pd->dialog, "hidetoolbarbtn");
 	conf_get_bool_value(DISABLE_TOOLBAR, &bSetting);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), bSetting);
 
@@ -612,96 +608,105 @@ preferences_dialog_init (PreferencesDialog *pd)
 		i = 0;
 
 	/* create toolbar style menu */
-	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->priv->dialog, "toolbarCombo"),
+	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->dialog, "toolbarCombo"),
 	                            gui_toolbar_style_options,
 	                            G_CALLBACK (on_gui_toolbar_style_changed),
 	                            i);
 
-	conf_bind (CONFIRM_MARK_ALL_READ, liferea_dialog_lookup (pd->priv->dialog, "confirmMarkAllReadButton"), "active", G_SETTINGS_BIND_DEFAULT);
+	conf_bind (CONFIRM_MARK_ALL_READ, liferea_dialog_lookup (pd->dialog, "confirmMarkAllReadButton"), "active", G_SETTINGS_BIND_DEFAULT);
 
 	/* ================= panel 5 "proxy" ======================== */
 
 #if WEBKIT_CHECK_VERSION (2, 15, 3)
-	gtk_widget_destroy (GTK_WIDGET (liferea_dialog_lookup (pd->priv->dialog, "proxyDisabledInfobar")));
+	gtk_widget_destroy (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "proxyDisabledInfobar")));
 	conf_get_str_value (PROXY_HOST, &proxy_host);
-	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->priv->dialog, "proxyhostentry")), proxy_host);
+	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->dialog, "proxyhostentry")), proxy_host);
 	g_free (proxy_host);
 
 	conf_get_int_value (PROXY_PORT, &proxy_port);
 	proxyport = g_strdup_printf ("%d", proxy_port);
-	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->priv->dialog, "proxyportentry")), proxyport);
+	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->dialog, "proxyportentry")), proxyport);
 	g_free (proxyport);
 
 	conf_get_bool_value (PROXY_USEAUTH, &enabled);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->priv->dialog, "useProxyAuth")), enabled);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "useProxyAuth")), enabled);
 
 	conf_get_str_value (PROXY_USER, &proxy_user);
-	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->priv->dialog, "proxyusernameentry")), proxy_user);
+	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->dialog, "proxyusernameentry")), proxy_user);
 	g_free (proxy_user);
 
 	conf_get_str_value (PROXY_PASSWD, &proxy_passwd);
-	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->priv->dialog, "proxypasswordentry")), proxy_passwd);
+	gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (pd->dialog, "proxypasswordentry")), proxy_passwd);
 	g_free (proxy_passwd);
 
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup(pd->priv->dialog, "proxyauthtable")), enabled);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup(pd->dialog, "proxyauthtable")), enabled);
 
 	conf_get_int_value (PROXY_DETECT_MODE, &i);
 	switch (i) {
 		default:
 		case 0: /* proxy auto detect */
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->priv->dialog, "proxyAutoDetectRadio")), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "proxyAutoDetectRadio")), TRUE);
 			enabled = FALSE;
 			break;
 		case 1: /* no proxy */
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->priv->dialog, "noProxyRadio")), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "noProxyRadio")), TRUE);
 			enabled = FALSE;
 			break;
 		case 2: /* manual proxy */
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->priv->dialog, "manualProxyRadio")), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (pd->dialog, "manualProxyRadio")), TRUE);
 			enabled = TRUE;
 			break;
 	}
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->priv->dialog, "proxybox")), enabled);
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "proxyAutoDetectRadio")), "clicked", G_CALLBACK (on_proxyAutoDetect_clicked), pd);
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "noProxyRadio")), "clicked", G_CALLBACK (on_noProxy_clicked), pd);
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "manualProxyRadio")), "clicked", G_CALLBACK (on_manualProxy_clicked), pd);
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "proxyhostentry")), "changed", G_CALLBACK (on_proxyhostentry_changed), pd);
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "proxyportentry")), "changed", G_CALLBACK (on_proxyportentry_changed), pd);
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "proxyusernameentry")), "changed", G_CALLBACK (on_proxyusernameentry_changed), pd);
-	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->priv->dialog, "proxypasswordentry")), "changed", G_CALLBACK (on_proxypasswordentry_changed), pd);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "proxybox")), enabled);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "proxyAutoDetectRadio")), "clicked", G_CALLBACK (on_proxyAutoDetect_clicked), pd);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "noProxyRadio")), "clicked", G_CALLBACK (on_noProxy_clicked), pd);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "manualProxyRadio")), "clicked", G_CALLBACK (on_manualProxy_clicked), pd);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "proxyhostentry")), "changed", G_CALLBACK (on_proxyhostentry_changed), pd);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "proxyportentry")), "changed", G_CALLBACK (on_proxyportentry_changed), pd);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "proxyusernameentry")), "changed", G_CALLBACK (on_proxyusernameentry_changed), pd);
+	g_signal_connect (G_OBJECT (liferea_dialog_lookup (pd->dialog, "proxypasswordentry")), "changed", G_CALLBACK (on_proxypasswordentry_changed), pd);
 #else
-	gtk_widget_show (GTK_WIDGET (liferea_dialog_lookup (pd->priv->dialog, "proxyDisabledInfobar")));
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->priv->dialog, "proxybox")), FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->priv->dialog, "proxyAutoDetectRadio")), TRUE);
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->priv->dialog, "noProxyRadio")), FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->priv->dialog, "manualProxyRadio")), FALSE);
+	gtk_widget_show (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "proxyDisabledInfobar")));
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "proxybox")), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "proxyAutoDetectRadio")), TRUE);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "noProxyRadio")), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "manualProxyRadio")), FALSE);
 #endif
 
 	/* ================= panel 6 "Privacy" ======================== */
 
-	widget = liferea_dialog_lookup (pd->priv->dialog, "donottrackbtn");
+	widget = liferea_dialog_lookup (pd->dialog, "donottrackbtn");
 	conf_get_bool_value (DO_NOT_TRACK, &bSetting);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), bSetting);
 
+#if WEBKIT_CHECK_VERSION (2, 30, 0)
+	gtk_widget_destroy (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "itpInfoBar")));
+	widget = liferea_dialog_lookup (pd->dialog, "itpbtn");
+	conf_get_bool_value (ENABLE_ITP, &bSetting);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), bSetting);
+#else
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "itpbtn")), FALSE);
+	gtk_widget_show (GTK_WIDGET (liferea_dialog_lookup (pd->dialog, "itpInfoBar")));
+#endif
 	/* ================= panel 7 "Enclosures" ======================== */
 
 	/* menu for download tool */
 	conf_get_int_value (DOWNLOAD_TOOL, &iSetting);
-	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->priv->dialog, "downloadToolCombo"),
+	ui_common_setup_combo_menu (liferea_dialog_lookup (pd->dialog, "downloadToolCombo"),
 	                            enclosure_download_tool_options,
 	                            G_CALLBACK (on_enclosure_download_tool_changed),
 	                            iSetting);
 
 	/* restore toggle */
 	conf_get_bool_value (DOWNLOAD_USE_CUSTOM_COMMAND, &bSetting);
-	widget = liferea_dialog_lookup (pd->priv->dialog, "customDownload");
+	widget = liferea_dialog_lookup (pd->dialog, "customDownload");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), bSetting);
-	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->priv->dialog, "customDownloadEntry"), bSetting);
-	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->priv->dialog, "downloadToolCombo"), !bSetting);
+	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->dialog, "customDownloadEntry"), bSetting);
+	gtk_widget_set_sensitive (liferea_dialog_lookup (pd->dialog, "downloadToolCombo"), !bSetting);
 
 	/* restore custom command */
 	conf_get_str_value (DOWNLOAD_CUSTOM_COMMAND, &custom_download_command);
-	widget = liferea_dialog_lookup (pd->priv->dialog, "customDownloadEntry");
+	widget = liferea_dialog_lookup (pd->dialog, "customDownloadEntry");
 	gtk_entry_set_text (GTK_ENTRY (widget), custom_download_command);
 	g_free (custom_download_command);
 
@@ -719,7 +724,7 @@ preferences_dialog_init (PreferencesDialog *pd)
 		list = g_slist_next (list);
 	}
 
-	widget = liferea_dialog_lookup (pd->priv->dialog, "enc_action_view");
+	widget = liferea_dialog_lookup (pd->dialog, "enc_action_view");
 	gtk_tree_view_set_model (GTK_TREE_VIEW (widget), GTK_TREE_MODEL (treestore));
 
 	column = gtk_tree_view_column_new_with_attributes (_("Type"), gtk_cell_renderer_text_new (), "text", FTS_TYPE, NULL);
@@ -731,18 +736,18 @@ preferences_dialog_init (PreferencesDialog *pd)
 
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW(widget)), GTK_SELECTION_SINGLE);
 
-	g_signal_connect_object (pd->priv->dialog, "destroy", G_CALLBACK (preferences_dialog_destroy_cb), pd, 0);
+	g_signal_connect_object (pd->dialog, "destroy", G_CALLBACK (preferences_dialog_destroy_cb), pd, 0);
 
-	gtk_widget_show_all (pd->priv->dialog);
+	gtk_widget_show_all (pd->dialog);
 
-	gtk_window_present (GTK_WINDOW (pd->priv->dialog));
+	gtk_window_present (GTK_WINDOW (pd->dialog));
 }
 
 void
 preferences_dialog_open (void)
 {
 	if (prefdialog) {
-		gtk_widget_show (prefdialog->priv->dialog);
+		gtk_widget_show (prefdialog->dialog);
 		return;
 	}
 
